@@ -33,7 +33,7 @@ except ImportError:
     from cgi import parse_qs
 
 __author__ = 'Daniel Lindsley'
-__version__ = ('0', '7', '0')
+__version__ = ('0', '8', '0')
 __license__ = 'BSD'
 
 
@@ -170,6 +170,15 @@ class Request(object):
 
         self.GET = self.build_get_dict()
 
+    def __getattr__(self, name):
+        """
+        Allow accesses of the environment if we don't already have an attribute
+        for. This lets you do things like::
+
+            script_name = request.SCRIPT_NAME
+        """
+        return self._environ[name]
+
     @lazyproperty
     def POST(self):
         return self.build_complex_dict()
@@ -198,7 +207,6 @@ class Request(object):
 
         return query_dict
 
-
     def build_complex_dict(self):
         """Takes POST/PUT data and rips it apart into a dict."""
         raw_data = cgi.FieldStorage(fp=StringIO.StringIO(self.body), environ=self._environ)
